@@ -9,7 +9,7 @@ Perl::Critic::Policy::Lax::RequireExplicitPackage::ExceptForPragmata
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
@@ -22,19 +22,20 @@ POD says:
   who that is.  Good encapsulation and common decency require your module to
   keep its innards to itself.
 
-Sure, that's swell for code that has effect at a package level, but some
-statements are lexical.  This policy makes allowance for just one of those
-cases: turning on strictures, warnings, and diagnostics.
+Sure, that's swell for code that has effect at a package level, but
+some statements are lexical.  This policy makes allowance for some of
+those cases.  By default, it permits turning on strictures, warnings,
+features, and diagnostics, as well as requiring a minimum Perl
+version.
 
-This module understands the C<exempt_scripts> configuration parameter just like
-L<Perl::Critic::Policy::Modules::RequireExplicitPackage>.
+=head1 METHODS
 
 =cut
 
 use Perl::Critic::Utils;
 use base qw(Perl::Critic::Policy);
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 my $EXPLANATION = 'Violates encapsulation';
 my $DESCRIPTION = 'Code (other than strict/warnings) not in explicit package';
@@ -43,29 +44,51 @@ sub default_severity { $SEVERITY_HIGH  }
 sub default_themes   { qw( risky )     }
 sub applies_to       { 'PPI::Document' }
 
-sub new {
-  my ($class, %args) = @_;
-  my $self = bless {}, $class;
+=head2 supported_parameters
 
-  #Set config, if defined
-  $self->{_exempt_scripts} =
-    defined $args{exempt_scripts} ? $args{exempt_scripts} : 1;
+The default list of pragmata that are permitted before a C<package>
+declaration can be changed via the C<allowed_pragmata> configuration
+parameter. Its value is a space-separated list of pragma names to be
+permitted.  In this list, the name C<perlversion> is special: it
+allows a C<use 5.xxx> statement.
 
-  return $self;
+This module understands the C<exempt_scripts> configuration parameter just like
+L<Perl::Critic::Policy::Modules::RequireExplicitPackage>.
+
+=cut
+
+sub supported_parameters {
+  return (
+	   {
+	     name => 'allowed_pragmata',
+	     description =>
+	       'Names of pragmata that are permitted before package declaration',
+	     default_string => 'diagnostics feature perlversion strict warnings',
+	     behavior => 'string list',
+	   },
+	   {
+	     name => 'exempt_scripts',
+	     description => q(Don't require programs to have a package statement.),
+	     default_string => '1',
+	     behavior => 'boolean',
+	   },
+	 );
 }
 
-# TODO: Make this configurable. -- rjbs, 2006-11-07
-my %allowed_pragmata = (
-  diagnostics => 1,
-  strict      => 1,
-  warnings    => 1,
-);
+sub initialize_if_enabled {
+  my($self, $config) = @_;
+  # The real parsing was done to spec in supported_parameters, but we
+  # convert the list to a hash here for ease of use later.
+  $self->{_allowed_pragmata} = { map { {$_ => 1} } @{$self->{_allowed_pragmata}} }
+    if ref $self->{_allowed_pragmata} eq 'ARRAY';
+  return $TRUE;
+}
 
 sub violates {
   my ($self, $elem, $doc) = @_;
 
   # You can configure this policy to exclude scripts
-  return if $self->{_exempt_scripts} && is_script($doc);
+  return if $self->{_exempt_scripts} && $doc->is_program;
 
   # Find the first 'package' statement
   my $package_stmnt = $doc->find_first('PPI::Statement::Package');
@@ -77,7 +100,8 @@ sub violates {
   my @non_packages =
     grep { not(
       $_->isa('PPI::Statement::Include') && $_->type eq 'use'
-      && exists $allowed_pragmata{ $_->module }
+      && ( $_->version && exists $self->{_allowed_pragmata}{perlversion} ||
+	 exists $self->{_allowed_pragmata}{ $_->module } )
     ) }
     grep { !$_->isa('PPI::Statement::Package') } @{$stmnts_ref};
   return if !@non_packages;
